==> haskell-string-interpolate-0.3.4.0-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-Jao2YBrlwjm4zm6LNFqrIQ
key:                  string-interpolate-0.3.4.0-Jao2YBrlwjm4zm6LNFqrIQ
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  ed8669df6448f3274b431a17ad7d6dcc
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-Jao2YBrlwjm4zm6LNFqrIQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-7NoEAFw0rGCrq6G2aaLlj
    haskell-src-meta-0.8.15-1apQCVxQPcDFI5Uzym58kA
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q template-haskell-2.19.0.0
    text-2.0.2 text-conversions-0.3.1.1-9i4A1ErnBL8EKgJbC7o4si
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-interpolate-0.3.4.0-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-1OofLkJHkQBlerRYEzUOe
key:                  string-interpolate-0.3.4.0-1OofLkJHkQBlerRYEzUOe
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  d813af53ca865f57c2fa56de241c92a2
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-1OofLkJHkQBlerRYEzUOe
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-IJp3jGoQkeD6bKOJwDjwr2
    haskell-src-meta-0.8.15-97ow0rQaH9KAcgq1IgIaIQ
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q template-haskell-2.19.0.0
    text-2.0.2 text-conversions-0.3.1.1-ZlO8I58HNa8AUfUumDjz2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
